@@ -102,8 +102,8 @@ impl Board {
                 PIN_A3: gpioa.pa0,
                 PIN_A8: gpiob.pb14,
                 PIN_A9: gpiob.pb15,
-                PIN_B5: gpioc.pc14,
-                PIN_B6: gpioc.pc13,
+                PIN_B5: gpioc.pc13,
+                PIN_B6: gpioc.pc14,
                 PIN_B7: gpiob.pb8,
                 PIN_B8: gpiob.pb9,
                 PIN_B9: gpiog.pg14,
@@ -127,7 +127,7 @@ impl Board {
                 PIN_D7: gpiod.pd2,
                 PIN_D8: gpioc.pc2,
                 PIN_D9: gpioc.pc3,
-                PIN_D10: gpiog.pg3,
+                PIN_D10: gpiod.pd3,
             },
             LED_USER: gpioc.pc7,
             #[cfg(feature = "seed")]
